@@ -16,32 +16,38 @@ class Context(Record):
     # TODO: Add State and country types
     def __init__(
             self,
-            key,
-            id,
+            record_key,
+            record_id,
             name=None,
             language=None,
             setting=None,
             country=None,
-            state=None
+            state=None,
+            container=None
     ):
-        super().__init__(key, id, Category.CONTEXT, name=name)
+        super().__init__(record_key, record_id, Category.CONTEXT, name=name, container=container)
+
+        if setting and not isinstance(setting, Setting):
+            raise Exception('setting arg for record {} must be an instance of Setting enum'
+                            .format(record_key))
+
+        self._setting = setting
         self._country = country
         self._state = state
-        self._setting = setting
         self._language = language
 
     @staticmethod
     def from_dict(context_dict):
-        id = context_dict.get('key')
-        setting = Setting.get_name(context_dict['setting'])
-        country = context_dict['country']
-        state = context_dict['state']
-        name = context_dict['name']
-        language = context_dict['language']
+        record_id = context_dict.get('key')
+        setting = Setting.get_name(context_dict.get('setting'))
+        country = context_dict.get('country')
+        state = context_dict.get('state')
+        name = context_dict.get('name')
+        language = context_dict.get('language')
 
         return Context(
-            key=id,
-            id=id,
+            record_key=record_id,
+            record_id=record_id,
             name=name,
             language=language,
             setting=setting,
@@ -51,8 +57,12 @@ class Context(Record):
 
     @staticmethod
     def from_databrary(context_dict):
-        id = context_dict.get('id')
+        rexord_id = context_dict.get('id')
         measures = context_dict.get('measures')
+
+        if not measures:
+            return Context(record_key=rexord_id, record_id=rexord_id)
+
         setting = Setting.get_name(measures.get('33'))
         country = measures.get('35')
         state = measures.get('36')
@@ -60,8 +70,8 @@ class Context(Record):
         language = measures.get('34')
 
         return Context(
-            key=id,
-            id=id,
+            record_key=rexord_id,
+            record_id=rexord_id,
             name=name,
             language=language,
             setting=setting,
@@ -69,30 +79,38 @@ class Context(Record):
             state=state
         )
 
-    def to_dict(self, template=False):
+    def get_template(self):
+        return {
+            "key": "{}".format(self.get_key()),
+            "name": self.get_name(),
+            "category": self.get_category().value,
+            "language": None,
+            "setting": None,
+            "state": None,
+            "country": None
+        }
+
+    def to_dict(self):
         result = {
             "key": "{}".format(self.get_key()),
             "name": self.get_name(),
             "category": self.get_category().value,
         }
 
-        if template or self.get_language() is not None:
-            result["language"] =  self.get_language()
+        if self.get_language() is not None:
+            result["language"] = self.get_language()
 
-        if template or self.get_setting() is not None:
+        if self.get_setting() is not None:
             result["setting"] = self.get_setting().value
 
-        if template or self.get_state() is not None:
-            result["state"] =  self.get_state()
+        if self.get_state() is not None:
+            result["state"] = self.get_state()
 
-        if template or self.get_country() is not None:
+        if self.get_country() is not None:
             result["country"] = self.get_country()
 
         return result
 
-    def to_json(self):
-        return json.dumps(self.to_dict())
-
     def get_language(self):
         return self._language
 
