@@ -2,10 +2,10 @@ from enum import Enum
 
 
 class Release(Enum):
-    PRIVATE = 'PRIVATE'
-    SHARED = 'SHARED'
-    EXCERPTS = 'EXCERPTS'
-    PUBLIC = 'PUBLIC'
+    PRIVATE = "PRIVATE"
+    SHARED = "SHARED"
+    EXCERPTS = "EXCERPTS"
+    PUBLIC = "PUBLIC"
 
     @classmethod
     def has_value(cls, value):
@@ -13,7 +13,4 @@ class Release(Enum):
 
     @classmethod
     def get_name(cls, value):
-        if value is None:
-            value = 'PRIVATE'
         return cls._value2member_map_[value]
-
