@@ -14,4 +14,7 @@ class Setting(Enum):
 
     @classmethod
     def get_name(cls, value):
+        if not cls.has_value(value):
+            return None
+
         return cls._value2member_map_[value]
